@@ -66,6 +66,8 @@ OutputType ThemeReader::getOutputType(const string &typeDesc) {
 void ThemeReader::initStyle(ElementStyle& style, const Diluculum::LuaVariable& var)
 {
 
+    style.setCustomStyle(""); // Init with a default value.
+
     if (var["Custom"].value()!=Diluculum::Nil) {
 
         int idx=1;
@@ -73,8 +75,10 @@ void ThemeReader::initStyle(ElementStyle& style, const Diluculum::LuaVariable& v
         while (var["Custom"][idx].value() !=Diluculum::Nil) {
 
             if (getOutputType(var["Custom"][idx]["Format"].value().asString()) == outputType) {
+
                 style.setCustomStyle (var["Custom"][idx]["Style"].value().asString() );
-                return;
+                style.setCustomOverride ( true );
+                break;
             }
             idx++;
         }
@@ -83,22 +87,30 @@ void ThemeReader::initStyle(ElementStyle& style, const Diluculum::LuaVariable& v
     string styleColor="#000000";
     bool styleBold=false, styleItalic=false, styleUnderline=false;
 
-    if (var["Colour"].value()!=Diluculum::Nil)
+    if (var["Colour"].value()!=Diluculum::Nil) {
         styleColor= var["Colour"].value().asString();
-    if (var["Bold"].value()!=Diluculum::Nil)
+        style.setCustomOverride(false);
+    }
+
+    if (var["Bold"].value()!=Diluculum::Nil) {
         styleBold= var["Bold"].value().asBoolean();
-    if (var["Italic"].value()!=Diluculum::Nil)
+        style.setCustomOverride(false);
+    }
+
+    if (var["Italic"].value()!=Diluculum::Nil) {
         styleItalic= var["Italic"].value().asBoolean();
-    if (var["Underline"].value()!=Diluculum::Nil)
+        style.setCustomOverride(false);
+    }
+
+    if (var["Underline"].value()!=Diluculum::Nil) {
         styleUnderline= var["Underline"].value().asBoolean();
+        style.setCustomOverride(false);
+    }
 
     style.setColour(Colour(styleColor));
     style.setBold(styleBold);
     style.setItalic(styleItalic);
     style.setUnderline(styleUnderline);
-
-    if (var["Underline"].value()!=Diluculum::Nil)
-        styleUnderline= var["Underline"].value().asBoolean();
 }
 
 bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type, bool loadSemanticStyles)
@@ -171,16 +183,17 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type, bo
         errorMessages.setColour(Colour("#ff0000"));
 
         if (outputType==HTML || outputType==XHTML) {
+            hover.setCustomOverride(true);
             hover.setCustomStyle ("cursor:help");
-            errorMessages.setCustomStyle ("color:red; border:solid 1px red; margin-left: 3em");
+            errorMessages.setCustomStyle ("border:solid 1px red; margin-left: 3em");
 
-            ostringstream lineColourFmt;
-            Colour lineColour = line.getColour();
-            lineColourFmt << "#"<<lineColour.getRed(HTML)<<lineColour.getGreen(HTML)<<lineColour.getBlue(HTML);
-            line.setCustomStyle("user-select: none; color: " + lineColourFmt.str());
+            if (line.getCustomStyle().empty()) {
+                line.setCustomStyle("user-select: none");
+            }
         }
 
         if (outputType==LATEX) {
+            errorMessages.setCustomOverride(true);
             errorMessages.setCustomStyle ("\\marginpar{\\small\\itshape\\color{red}#1}");
         }
 
@@ -198,6 +211,9 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type, bo
             initStyle(errors, ls["Error"]);
         }
 
+        keywordStyles.clear();
+        semanticStyleMap.clear();
+
         int idx=1;
         ElementStyle kwStyle;
         char kwName[5];
@@ -219,8 +235,6 @@ bool ThemeReader::load ( const string &styleDefinitionPath , OutputType type, bo
                 snprintf(kwName, sizeof(kwName), "st%c", ('a'+idx+-1));
                 keywordStyles.insert ( make_pair ( string(kwName), kwStyle ));
                 semanticStyleMap[ls["SemanticTokenTypes"][idx]["Type"].value().asString()] = keywordStyleCnt + idx;
-                //std::cerr<<"semanticStyleMap "<< (ls["SemanticTokenTypes"][idx]["Type"].value().asString()) << " -> "<< keywordStyleCnt + idx<<"\n";
-
                 idx++;
             }
         }
